(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    100201,       2352]
NotebookOptionsPosition[     97551,       2270]
NotebookOutlinePosition[     98311,       2295]
CellTagsIndexPosition[     98268,       2292]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "\n",
 StyleBox["\n",
  FontSize->24],
 StyleBox["Using bootstrap to estimate rates of HIV escape from CD8 T cell \
responses\n",
  FontSize->30],
 StyleBox["\nSeptember 2017\n",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->GrayLevel[0]]
}], "Title",
 CellFrame->3,
 CellChangeTimes->{{3.674577198325708*^9, 3.6745772185991592`*^9}, {
  3.715621557692621*^9, 3.715621581472478*^9}},
 TextAlignment->Center,
 FontSize->16,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 0],
 Background->RGBColor[0.65626, 0.660166, 0.87892]],

Cell[CellGroupData[{

Cell["\<\
Fitting one escape from Goonetilleke et al. JEM 2009 (CH40, Env435)\
\>", "Subsection",
 CellMargins->{{60, Inherited}, {Inherited, Inherited}},
 CellChangeTimes->{{3.6745775105577497`*^9, 3.6745775115802813`*^9}, {
  3.674593999962175*^9, 3.6745940031382017`*^9}, {3.715621706574977*^9, 
  3.715621716597951*^9}, {3.715621748288824*^9, 3.715621752712543*^9}},
 FontColor->RGBColor[1, 0, 0]],

Cell["This is a function providing a fit.", "Text",
 CellChangeTimes->{{3.715636769887259*^9, 3.715636867737747*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"minimum2r", "[", 
    RowBox[{
    "array_", ",", "func_", ",", "pars_", ",", "initpars_", ",", "conpars_", 
     ",", "opt___"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "temp1", ",", "fpar", ",", "par0", ",", "npar", ",", "constr0", ",", 
       "newpars", ",", "i", ",", "temp", ",", "temp0", ",", "Constrain0", ",",
        "ww"}], "}"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fpar", ",", "par0", ",", "constr0"}], "}"}], "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Cases", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"pars", ",", "initpars", ",", "conpars"}], "}"}], "]"}], 
          ",", 
          RowBox[{"x_", "?", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"!", 
              RowBox[{"NumericQ", "[", 
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "&"}], ")"}]}]}], 
         "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ww", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], ",", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "^", "2"}]}], ",", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], "&"}], ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"pars", ",", "conpars"}], "}"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"NumericQ", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Constrain", "/.", "opt"}], ")"}], "/.", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"fpar", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
             RowBox[{"initpars", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"Length", "[", "fpar", "]"}]}], "}"}]}], "]"}]}], "]"}],
         ",", 
        RowBox[{"Constrain0", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Constrain", "/.", "opt"}], ")"}], "/.", "ww"}]}], ",", 
        RowBox[{"Constrain0", "=", "0"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"par0", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], ",", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "&"}], ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"par0", ",", "constr0"}], "}"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"newpars", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], "&&", 
             RowBox[{"!", 
              RowBox[{"NumericQ", "[", 
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}], ",", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "^", "2"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "&"}], ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"pars", ",", "conpars"}], "}"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"npar", "=", 
       RowBox[{"Length", "[", "fpar", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"temp", "=", 
       RowBox[{"FindMinimum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"func", "[", 
           RowBox[{"array", ",", "newpars"}], "]"}], "+", "Constrain0"}], ",", 
         RowBox[{
          RowBox[{"Split", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"fpar", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"par0", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", 
                RowBox[{"1.01", "*", 
                 RowBox[{"par0", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", "npar"}], "}"}]}], "]"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"#1", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
              RowBox[{"#2", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"AccuracyGoal", "\[Rule]", "eps"}], ",", 
         RowBox[{"PrecisionGoal", "\[Rule]", "eps"}], ",", 
         RowBox[{"MaxIterations", "\[Rule]", 
          RowBox[{"10", "^", "4"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"temp1", "=", "temp"}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "1"}], ",", 
        RowBox[{"i", "\[LessEqual]", "npar"}], ",", 
        RowBox[{"i", "++"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"constr0", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "1"}], ",", 
          RowBox[{
           RowBox[{"temp", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "i", ",", "2"}], "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"temp", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "i", ",", "2"}], "]"}], "]"}], ")"}], "^", 
            "2"}]}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"temp0", "=", 
         RowBox[{
          RowBox[{"Split", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"fpar", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"newpars", "/.", 
                   RowBox[{"temp", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", "npar"}], "}"}]}], "]"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"#1", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", 
              RowBox[{"#2", "[", 
               RowBox[{"[", "1", "]"}], "]"}]}], "&"}]}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"temp", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "=", 
         RowBox[{"Flatten", "[", "temp0", "]"}]}], ";"}], "*)"}], 
      RowBox[{"ClearAll", "[", 
       RowBox[{
       "npar", ",", "fpar", ",", "par0", ",", "constr0", ",", "newpars"}], 
       "]"}], ";", "\[IndentingNewLine]", "temp"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7156222025511913`*^9, 3.715622202551969*^9}, 
   3.715636721479767*^9}],

Cell[TextData[{
 "Data are given in the variable ",
 StyleBox["datasetT", "Input"],
 ". Data must be given in the form of the list with (t,f,N) where t is the \
time of sampling, f is the frequency of escape variant, and N is the number \
of sequences in the sample."
}], "Text",
 CellChangeTimes->{{3.715636769887259*^9, 3.71563696381048*^9}, 
   3.719964834611759*^9},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"Fitting", " ", "a", " ", "given", " ", 
     RowBox[{"dataset", ":", " ", 
      RowBox[{"CH40", " ", "and", " ", "Env435", " ", "epitope"}]}]}], " ", 
    "*)"}],
   FontColor->RGBColor[0, 0, 1]], 
  StyleBox["\[IndentingNewLine]",
   FontColor->RGBColor[0, 0, 1]], 
  StyleBox["\[IndentingNewLine]",
   FontColor->RGBColor[0, 0, 1]], 
  RowBox[{
   RowBox[{
    RowBox[{"datasetT", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0.`", ",", "28"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"16", ",", "0.`", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"45", ",", "0.`", ",", "14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"111", ",", "0.`", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"181", ",", "0.14`", ",", "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"412", ",", "1.`", ",", "12"}], "}"}]}], "}"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"CH40", " ", "Env", " ", "435"}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"timetemp", "=", 
     RowBox[{"datasetT", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tmax", "=", 
     RowBox[{"Max", "[", "timetemp", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T0", "=", "0"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.606434667871175*^9, {3.606434720517824*^9, 3.606434737734758*^9}, {
   3.606435238550329*^9, 3.60643523882753*^9}, {3.606435270451669*^9, 
   3.606435290403308*^9}, {3.606435330711084*^9, 3.6064353433837*^9}, {
   3.674559732000701*^9, 3.674559751557068*^9}, 3.674560667698694*^9, {
   3.674569855811623*^9, 3.6745698560994587`*^9}, {3.674578335579227*^9, 
   3.674578335649626*^9}, {3.674578651689075*^9, 3.674578651776465*^9}, 
   3.674579015382513*^9, {3.674579606218246*^9, 3.674579606401672*^9}, 
   3.674579676529653*^9, 3.674579840618122*^9, {3.674580141307755*^9, 
   3.674580157511879*^9}, {3.6745803509858313`*^9, 3.6745803510892563`*^9}, 
   3.674580494435482*^9, 3.674592448222978*^9, {3.674592506268749*^9, 
   3.674592522067998*^9}, 3.674592835837592*^9, {3.674592974728541*^9, 
   3.674592976871028*^9}, {3.674593094330637*^9, 3.67459310417135*^9}, {
   3.674593167599471*^9, 3.6745931929246273`*^9}, {3.6745933578606873`*^9, 
   3.674593358084059*^9}, 3.6745936823234577`*^9, 3.67459388043417*^9, {
   3.715621691249412*^9, 3.7156216935692587`*^9}, {3.7156217695759907`*^9, 
   3.715621779871236*^9}, {3.7156220680872717`*^9, 3.715622077439034*^9}, {
   3.715636967708428*^9, 3.715636974138259*^9}}],

Cell[TextData[{
 "Here we define the logistic equation model (given by the function ",
 StyleBox["freq", "Input"],
 " with ",
 StyleBox["p0", "Input"],
 " being the initial escape variant frequency and ",
 StyleBox["K", "Input"],
 " being the escape rate). Because likelihood breaks when predicted frequency \
reaches 0 or 1, we use an extra dummy variable ",
 StyleBox["fs", "Input"],
 " which prevents the frequency from ever reaching the values 0 or 1. Final \
function for the logistic equation is given by ",
 StyleBox["f", "Input"],
 ". The function ",
 StyleBox["ssq", "Input"],
 " defines likelihood of the model for the data. Other variables are defined \
for fitting model to data (ParF, FitPars,ConPars)."
}], "Text",
 CellChangeTimes->{{3.715636769887259*^9, 3.71563696381048*^9}, {
  3.715637009846251*^9, 3.715637100547566*^9}, {3.7156371312023077`*^9, 
  3.715637142542602*^9}, {3.7156371776424713`*^9, 3.715637193600957*^9}, {
  3.715637241237433*^9, 3.7156372530285788`*^9}, {3.7199648442584677`*^9, 
  3.719964844649137*^9}, {3.7199648823451242`*^9, 3.719964941434238*^9}, {
  3.719964973049369*^9, 3.719964974184198*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "array", ",", "pars", ",", "ssq", ",", "f", ",", "f0", ",", "fs"}], "]"}],
    ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fs", "=", 
   RowBox[{"10", "^", 
    RowBox[{"-", "10"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"freq", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"{", 
       RowBox[{"p0_", ",", "K_"}], "}"}]}], "]"}], ":=", 
    RowBox[{"p0", "/", 
     RowBox[{"(", 
      RowBox[{"p0", "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "p0"}], ")"}], "*", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "K"}], "*", "t"}], "]"}]}]}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f0", "[", 
    RowBox[{"t_", ",", 
     RowBox[{"{", 
      RowBox[{"p0_", ",", "K_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"p0", ">=", "1"}], ",", 
     RowBox[{"freq", "[", 
      RowBox[{"t", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "-", "fs"}], ",", "K"}], "}"}]}], "]"}], ",", 
     RowBox[{"freq", "[", 
      RowBox[{"t", ",", 
       RowBox[{"{", 
        RowBox[{"p0", ",", "K"}], "}"}]}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"t_", ",", "par_"}], "]"}], ":=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f0", "[", 
        RowBox[{"t", ",", "par"}], "]"}], "<", "fs"}], ",", "fs", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"f0", "[", 
          RowBox[{"t", ",", "par"}], "]"}], ">", 
         RowBox[{"1", "-", "fs"}]}], ",", 
        RowBox[{"1", "-", "fs"}], ",", "\[IndentingNewLine]", 
        RowBox[{"f0", "[", 
         RowBox[{"t", ",", "par"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eps", "=", "10"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ssq", "[", 
     RowBox[{"array_", ",", "pars_"}], "]"}], ":=", 
    RowBox[{"Re", "[", 
     RowBox[{"Total", "[", 
      RowBox[{"-", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "*", 
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "*", 
            RowBox[{"Log", "[", 
             RowBox[{"f", "[", 
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "pars"}], "]"}], "]"}]}],
            "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "*", 
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "*", 
            RowBox[{"Log", "[", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"f", "[", 
                RowBox[{
                 RowBox[{"#", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], ",", "pars"}], "]"}]}], 
              ")"}], "]"}]}]}], "&"}], ",", "array"}], "]"}]}], "]"}], 
     "]"}]}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Par0", "=", 
    RowBox[{"{", 
     RowBox[{"0.011520314894210692`", ",", "0.075851716170325`"}], "}"}]}], 
   ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"Initial", " ", "guesses", " ", "for", " ", "parameters"}], " ", 
   "*)"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{"F0", ",", "e"}], "]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"AllPars", "=", 
    RowBox[{"{", 
     RowBox[{"F0", ",", "e"}], "}"}]}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"Define", " ", "parameters", " ", "of", " ", "the", " ", "model"}],
    " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"Npar", "=", 
   RowBox[{"Length", "[", "AllPars", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FitPars", "=", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}], ";"}], "    ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "defining", " ", "which", " ", "parameters", " ", "will", " ", "be", " ", 
    "fitted"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"ParF", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"FitPars", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "1"}], ",", 
       RowBox[{"AllPars", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"Par0", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "Npar"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ConPars", "=", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "which", " ", "parameters", " ", "will", " ", "be", " ", "constrained", 
    " ", "to", " ", "be", " ", "positive"}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Parameters to be fitted are \>\"", ",", 
    RowBox[{"Cases", "[", 
     RowBox[{
      RowBox[{"AllPars", "*", "FitPars"}], ",", 
      RowBox[{"x_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"NumericQ", "[", "#", "]"}]}], "&"}], ")"}]}]}], "]"}]}], 
   "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Parameters to be constrained (i.e. to be > 0) are \>\"", ",", 
     RowBox[{"Cases", "[", 
      RowBox[{
       RowBox[{"AllPars", "*", "ConPars"}], ",", 
       RowBox[{"x_", "?", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"NumericQ", "[", "#", "]"}]}], "&"}], ")"}]}]}], "]"}]}], 
    "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"ssq", "[", 
  RowBox[{"datasetT", ",", "Par0"}], "]"}]}], "Input",
 CellChangeTimes->{{3.60643475028312*^9, 3.606434809574314*^9}, {
   3.606434867746605*^9, 3.606434886888223*^9}, {3.674559696000758*^9, 
   3.674559702273102*^9}, {3.6745597734263973`*^9, 3.674559828242481*^9}, {
   3.674559861587879*^9, 3.674559897574932*^9}, {3.6745687673972273`*^9, 
   3.674568767660779*^9}, 3.6745698689194927`*^9, {3.6745783433315153`*^9, 
   3.674578347370501*^9}, {3.674578848385551*^9, 3.6745788505611067`*^9}, {
   3.674579024294467*^9, 3.6745790597505207`*^9}, {3.674592545532692*^9, 
   3.674592585138113*^9}, 3.6745927126489573`*^9, {3.674593203238389*^9, 
   3.674593203564817*^9}, 3.715622075089015*^9, {3.715622148530034*^9, 
   3.715622153032926*^9}, 3.715622220149268*^9, 3.715622254057679*^9, {
   3.715636708952001*^9, 3.715636710102404*^9}, 3.715636994035049*^9, {
   3.7156371553588533`*^9, 3.715637165654173*^9}, {3.715637196266665*^9, 
   3.715637234774296*^9}, {3.715637319268466*^9, 3.715637336007303*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Parameters to be fitted are \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"F0", ",", "e"}], "}"}]}],
  SequenceForm[
  "Parameters to be fitted are ", {$CellContext`F0, $CellContext`e}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.606434870431307*^9, 3.606434890841864*^9}, 
   3.606435241269479*^9, {3.60643527238514*^9, 3.606435291796709*^9}, 
   3.606435333070819*^9, {3.674559754156555*^9, 3.674559828692882*^9}, {
   3.6745598873162813`*^9, 3.674559897969702*^9}, 3.674560669617446*^9, 
   3.674568768448619*^9, {3.6745698591913643`*^9, 3.6745698693802156`*^9}, {
   3.674578339126997*^9, 3.674578368589808*^9}, 3.6745786534923143`*^9, {
   3.67457901717242*^9, 3.674579035629167*^9}, 3.674579611005577*^9, 
   3.674579679934676*^9, 3.674579844540718*^9, 3.6745801607660437`*^9, {
   3.6745803525671988`*^9, 3.674580376303782*^9}, 3.6745804958851233`*^9, 
   3.6745924496961813`*^9, {3.6745925238780613`*^9, 3.674592585548873*^9}, 
   3.6745927130199003`*^9, 3.674592837575688*^9, 3.6745929791601543`*^9, {
   3.6745931495283613`*^9, 3.674593203936561*^9}, 3.67459336024319*^9, 
   3.674593684530671*^9, 3.6745938829827547`*^9, 3.715621630274603*^9, 
   3.715621782288805*^9, 3.7156220843347063`*^9, 3.715622154412179*^9, 
   3.715622220571517*^9, 3.715622263473155*^9, 3.7156366177383337`*^9, 
   3.7156366655569363`*^9, {3.715636710599497*^9, 3.715636723544202*^9}, {
   3.715637167770837*^9, 3.715637171922983*^9}, {3.7156372380145903`*^9, 
   3.7156372551009502`*^9}, 3.715637337051898*^9, 3.7199649775822763`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Parameters to be constrained (i.e. to be > 0) are \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"F0", ",", "e"}], "}"}]}],
  SequenceForm[
  "Parameters to be constrained (i.e. to be > 0) are ", {$CellContext`F0, \
$CellContext`e}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.606434870431307*^9, 3.606434890841864*^9}, 
   3.606435241269479*^9, {3.60643527238514*^9, 3.606435291796709*^9}, 
   3.606435333070819*^9, {3.674559754156555*^9, 3.674559828692882*^9}, {
   3.6745598873162813`*^9, 3.674559897969702*^9}, 3.674560669617446*^9, 
   3.674568768448619*^9, {3.6745698591913643`*^9, 3.6745698693802156`*^9}, {
   3.674578339126997*^9, 3.674578368589808*^9}, 3.6745786534923143`*^9, {
   3.67457901717242*^9, 3.674579035629167*^9}, 3.674579611005577*^9, 
   3.674579679934676*^9, 3.674579844540718*^9, 3.6745801607660437`*^9, {
   3.6745803525671988`*^9, 3.674580376303782*^9}, 3.6745804958851233`*^9, 
   3.6745924496961813`*^9, {3.6745925238780613`*^9, 3.674592585548873*^9}, 
   3.6745927130199003`*^9, 3.674592837575688*^9, 3.6745929791601543`*^9, {
   3.6745931495283613`*^9, 3.674593203936561*^9}, 3.67459336024319*^9, 
   3.674593684530671*^9, 3.6745938829827547`*^9, 3.715621630274603*^9, 
   3.715621782288805*^9, 3.7156220843347063`*^9, 3.715622154412179*^9, 
   3.715622220571517*^9, 3.715622263473155*^9, 3.7156366177383337`*^9, 
   3.7156366655569363`*^9, {3.715636710599497*^9, 3.715636723544202*^9}, {
   3.715637167770837*^9, 3.715637171922983*^9}, {3.7156372380145903`*^9, 
   3.7156372551009502`*^9}, 3.715637337051898*^9, 3.719964977592038*^9}],

Cell[BoxData["96.63749835133352`"], "Output",
 CellChangeTimes->{{3.606434870437173*^9, 3.606434890848607*^9}, 
   3.606435241404709*^9, {3.60643527247155*^9, 3.606435291886501*^9}, 
   3.606435333080295*^9, {3.674559754173614*^9, 3.674559828710828*^9}, {
   3.674559887338306*^9, 3.67455989798755*^9}, 3.6745606696334*^9, 
   3.6745687684663363`*^9, {3.674569859209424*^9, 3.6745698693973217`*^9}, {
   3.6745783391456614`*^9, 3.6745783686083727`*^9}, 3.6745786535097227`*^9, {
   3.6745790171903667`*^9, 3.6745790356472063`*^9}, 3.674579611023888*^9, 
   3.674579679952571*^9, 3.674579844558467*^9, 3.674580160786278*^9, {
   3.6745803525845737`*^9, 3.674580376321151*^9}, 3.674580495903984*^9, 
   3.674592449713978*^9, {3.674592523898919*^9, 3.6745925855663567`*^9}, 
   3.674592713038073*^9, 3.674592837601428*^9, 3.674592979181973*^9, {
   3.674593149546053*^9, 3.674593203956317*^9}, 3.674593360265543*^9, 
   3.67459368454732*^9, 3.674593882999433*^9, 3.71562163029037*^9, 
   3.715621782306046*^9, 3.715622084352276*^9, 3.715622154429646*^9, 
   3.7156222205884523`*^9, 3.7156222634912233`*^9, 3.7156366177685843`*^9, 
   3.7156366655741034`*^9, {3.715636710618696*^9, 3.715636723560741*^9}, {
   3.715637167787711*^9, 3.715637171939148*^9}, {3.715637238026506*^9, 
   3.7156372551162853`*^9}, 3.715637337069525*^9, 3.719964977598938*^9}]
}, Open  ]],

Cell["\<\
Here we now fit the basic logistic model to the data. The fit converges but \
with an error indicating that optimal fit cannot be found. This is not \
surprising because for these data the optimal fit is found with escape rate \
being unbounded. \
\>", "Text",
 CellChangeTimes->{{3.715636769887259*^9, 3.715636833997158*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"datasetT", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotMarkers", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[FilledCircle]\>\"", ",", "16"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.03"}], ",", "1.03"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<days\>\"", ",", "\"\<fraction mutant\>\""}], "}"}]}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
        RowBox[{"FontFamily", "\[Rule]", "Times"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", 
          RowBox[{"f", "[", 
           RowBox[{"t", ",", "Par0"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotMarkers", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<days since seroconversion\>\"", ",", 
        "\"\<consensus frequency\>\""}], "}"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.60643475028312*^9, 3.606434809574314*^9}, {
   3.606434867746605*^9, 3.606434872639884*^9}, {3.60643493454702*^9, 
   3.606434935815521*^9}, {3.674579687212658*^9, 3.674579708869301*^9}, 
   3.674580387562258*^9, {3.6745924578706427`*^9, 3.674592460590288*^9}, {
   3.674592579090499*^9, 3.6745925797776203`*^9}, {3.715621793859888*^9, 
   3.715621797922167*^9}, {3.715622096142693*^9, 3.715622111740417*^9}, {
   3.7156222278671513`*^9, 3.715622238491489*^9}, {3.7156372614954844`*^9, 
   3.715637283435706*^9}, {3.719964954554925*^9, 3.7199649642661867`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->16], {0., 0.}], {{{0., 0.}}, {{16., 0.}}, {{45., 0.}}, {{
        111., 0.}}, {{181., 0.14}}, {{412., 1.}}}],
       FontFamily->Times,
       FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.007333333333333334], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJxdz3lczfn+B/AzMTF3GI1scy1zMDPXUpYkRoyXteyHUknldNr3s5YlnGyD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       "]]}}, {}, {}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 16, FontFamily -> Times},
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox["\"fraction mutant\"", TraditionalForm], None}, {
     FormBox["\"days\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 412.}, {-0.03, 1.03}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.606434757904995*^9, 3.606434810142064*^9}, 
   3.606434936445892*^9, {3.606435249190312*^9, 3.606435293118161*^9}, 
   3.606435334134918*^9, {3.674559792023429*^9, 3.6745598296374817`*^9}, {
   3.6745598888620996`*^9, 3.674559898820855*^9}, 3.674560670885633*^9, 
   3.6745687698901176`*^9, {3.6745698606644983`*^9, 3.6745698703383083`*^9}, {
   3.6745783523253393`*^9, 3.674578369826573*^9}, 3.6745786549966993`*^9, {
   3.674579018371706*^9, 3.674579036724025*^9}, 3.6745796121212378`*^9, {
   3.67457968090559*^9, 3.674579709414412*^9}, 3.674579845884304*^9, 
   3.6745801628099546`*^9, {3.674580354082732*^9, 3.674580388283391*^9}, 
   3.674580497019631*^9, {3.674592451202602*^9, 3.674592461093924*^9}, {
   3.674592525048517*^9, 3.674592586542739*^9}, 3.674592713970386*^9, 
   3.6745928389401693`*^9, 3.674592980374937*^9, {3.6745931532618093`*^9, 
   3.6745932047905827`*^9}, 3.674593361316106*^9, 3.674593686066028*^9, 
   3.674593884481086*^9, 3.715621631817621*^9, {3.7156217871400127`*^9, 
   3.7156217984340153`*^9}, {3.715622085924818*^9, 3.7156221123187733`*^9}, 
   3.715622155803522*^9, {3.715622222750505*^9, 3.71562226450445*^9}, 
   3.71563661899889*^9, 3.715636666886777*^9, {3.715636711995327*^9, 
   3.7156367412301598`*^9}, {3.715637257067258*^9, 3.715637284030716*^9}, 
   3.715637339051901*^9, 3.719964980040094*^9}]
}, Open  ]],

Cell["\<\
Here we now fit the basic logistic model to the data. The fit converges but \
with an error indicating that optimal fit cannot be found. This is not \
surprising because for these data the optimal fit is found with escape rate \
being unbounded. \
\>", "Text",
 CellChangeTimes->{{3.715636769887259*^9, 3.715636833997158*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"Fitting", " ", "frequency", " ", 
     RowBox[{"dynamics", ":", " ", 
      RowBox[{"constant", " ", "escape", " ", "rate"}]}]}], " ", "*)"}],
   FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"sol", "=", 
    RowBox[{"minimum2r", "[", 
     RowBox[{
     "datasetT", ",", "ssq", ",", "ParF", ",", "Par0", ",", "ConPars"}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"NumericQ", "[", 
       RowBox[{"sol", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
      RowBox[{"Par0", "=", 
       RowBox[{"ParF", "/.", 
        RowBox[{"sol", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "Par0"}]}]], "Input",
 CellChangeTimes->{
  3.606434817237395*^9, {3.606434942810667*^9, 3.606434943908833*^9}, 
   3.674559821513281*^9, {3.6745927969989023`*^9, 3.674592812727335*^9}, {
   3.715636621236425*^9, 3.715636623995336*^9}, {3.715636754140937*^9, 
   3.715636763923213*^9}}],

Cell[BoxData[
 TemplateBox[{
  "FindMinimum","fmmp",
   "\"Machine precision is insufficient to achieve the requested accuracy or \
precision.\"",2,136,1,26356255780359393245,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.715636625596511*^9, 3.715636667944889*^9, 3.7156367153735247`*^9, {
   3.715636748378285*^9, 3.715636754796217*^9}, 3.7156372968266706`*^9, 
   3.715637353875204*^9, 3.719964985749414*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.835215765083443`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"F0", "\[Rule]", "1.435397947235927`*^-10"}], ",", 
     RowBox[{"e", "\[Rule]", "0.11516017274748384`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.715636625839625*^9, 3.715636668172978*^9, 3.715636715389751*^9, {
   3.715636748397209*^9, 3.715636754816353*^9}, 3.715637296844651*^9, 
   3.715637353893408*^9, 3.719964985767157*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.435397947235927`*^-10", ",", "0.11516017274748384`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.715636625839625*^9, 3.715636668172978*^9, 3.715636715389751*^9, {
   3.715636748397209*^9, 3.715636754816353*^9}, 3.715637296844651*^9, 
   3.715637353893408*^9, 3.719964985774536*^9}]
}, Open  ]],

Cell["Model fit given these estimated parameters", "Text",
 CellChangeTimes->{{3.715636769887259*^9, 3.715636833997158*^9}, {
  3.7156373641495523`*^9, 3.715637372787093*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"datasetT", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotMarkers", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[FilledCircle]\>\"", ",", "16"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.03"}], ",", "1.03"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<days\>\"", ",", "\"\<fraction mutant\>\""}], "}"}]}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
        RowBox[{"FontFamily", "\[Rule]", "Times"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", 
          RowBox[{"f", "[", 
           RowBox[{"t", ",", "Par0"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotMarkers", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<days since seroconversion\>\"", ",", 
        "\"\<consensus frequency\>\""}], "}"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.60643475028312*^9, 3.606434809574314*^9}, {
   3.606434867746605*^9, 3.606434872639884*^9}, {3.60643493454702*^9, 
   3.606434935815521*^9}, {3.674579687212658*^9, 3.674579708869301*^9}, 
   3.674580387562258*^9, {3.6745924578706427`*^9, 3.674592460590288*^9}, {
   3.674592579090499*^9, 3.6745925797776203`*^9}, {3.715621793859888*^9, 
   3.715621797922167*^9}, {3.715622096142693*^9, 3.715622111740417*^9}, {
   3.7156222278671513`*^9, 3.715622238491489*^9}, {3.7156372614954844`*^9, 
   3.715637283435706*^9}, {3.71996500661607*^9, 3.7199650069443607`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledCircle]\"\>",
          StripOnInput->False,
          FontSize->16], {0., 0.}], {{{0., 0.}}, {{16., 0.}}, {{45., 0.}}, {{
        111., 0.}}, {{181., 0.14}}, {{412., 1.}}}],
       FontFamily->Times,
       FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.007333333333333334], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJxd1Xk4lfn/x/GDTCUTzVSTZJJSGKFUKhkvQtpljahjy87Zz0mbom1kUtM6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       "]]}}, {}, {}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 16, FontFamily -> Times},
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox["\"fraction mutant\"", TraditionalForm], None}, {
     FormBox["\"days\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 412.}, {-0.03, 1.03}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.715637350654005*^9, 3.715637354799625*^9}, {
  3.719964995825033*^9, 3.719965007609022*^9}}]
}, Open  ]],

Cell["Here we now resample the data using Beta distribution.", "Text",
 CellChangeTimes->{{3.715636769887259*^9, 3.715636833997158*^9}, {
  3.715637381483746*^9, 3.715637407191716*^9}, {3.7156375084742603`*^9, 
  3.7156375089786587`*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "resampling", " ", "data", " ", "using", " ", "Beta", " ", 
     "distribution"}], " ", "*)"}],
   FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"random", "[", "temp_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "n"}], "}"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "n"}], "}"}], "=", "temp"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Random", "[", 
         RowBox[{"BetaDistribution", "[", 
          RowBox[{
           RowBox[{"x", "+", 
            RowBox[{"1", "/", "2"}]}], ",", 
           RowBox[{"n", "-", "x", "+", 
            RowBox[{"1", "/", "2"}]}]}], "]"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Nboot", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"BootstrapData", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{"random", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "*", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "3", "]"}], "]"}]}], ",", 
               RowBox[{"#", "[", 
                RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "&"}], ",", 
         "datasetT"}], "]"}], ",", 
       RowBox[{"{", "Nboot", "}"}]}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.674559944507058*^9, 3.674559946278452*^9}, {
  3.674560114197371*^9, 3.674560125363679*^9}, {3.674560192404852*^9, 
  3.674560205314351*^9}, {3.719965029334676*^9, 3.719965030004917*^9}}],

Cell["Here we fit the model to all bootstrapped samples. ", "Text",
 CellChangeTimes->{{3.715636769887259*^9, 3.715636833997158*^9}, {
  3.715637381483746*^9, 3.715637407191716*^9}, {3.7156374982848997`*^9, 
  3.7156375055303373`*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Par00", "=", 
   RowBox[{"{", 
    RowBox[{"0.0011520314894210692`", ",", "0.038075851716170325`"}], "}"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solData0", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"minimum2r", "[", 
       RowBox[{"#", ",", "ssq", ",", "ParF", ",", "Par00", ",", "ConPars"}], 
       "]"}], "&"}], ",", "BootstrapData"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.674559920171835*^9, 3.6745599211234627`*^9}, {
   3.6745784389276333`*^9, 3.6745784421019297`*^9}, {3.674578830547029*^9, 
   3.674578832520028*^9}, 3.674579342497347*^9, 3.6745926015248327`*^9}],

Cell["\<\
Now we analyze the results and calculate mean values and 95% CIs from the \
bootstrapped estimates.\
\>", "Text",
 CellChangeTimes->{{3.715636769887259*^9, 3.715636833997158*^9}, {
  3.715637381483746*^9, 3.715637407191716*^9}, {3.715637516739068*^9, 
  3.715637537864131*^9}, {3.719965039258243*^9, 3.719965040947097*^9}, {
  3.7199651003164997`*^9, 3.719965102500288*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"CI", "=", "0.95"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"solData", "=", 
   RowBox[{"Cases", "[", 
    RowBox[{"solData0", ",", 
     RowBox[{"x_", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"NumericQ", "[", 
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}], "&"}], ")"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "solData", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tPars", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"ParF", ",", 
     RowBox[{
      RowBox[{"1", "/", "e"}], "*", 
      RowBox[{"Log", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "F0"}], ")"}], "/", "F0"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BestFitParameters", "=", 
   RowBox[{"tPars", "/.", 
    RowBox[{"sol", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ParametersData", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"tPars", "/.", 
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "&"}], ",", "solData"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mCI", "=", 
   RowBox[{"Length", "[", "ParametersData", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"printPar", "=", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ToString", "[", "#", "]"}], "<>", "\"\< = \>\""}], "&"}], 
      ",", "tPars"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Mean and Bootstrap \>\"", ",", 
    RowBox[{"Round", "[", 
     RowBox[{"CI", "*", "100"}], "]"}], ",", 
    "\"\<% confindence intervals (based on \>\"", ",", "mCI", ",", 
    "\"\< resamplings)\>\""}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "\[LessEqual]", 
     RowBox[{"Length", "[", "printPar", "]"}]}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"printPar", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"BestFitParameters", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", "\"\< mean bootstrap = \>\"", ",", 
      RowBox[{"Mean", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", "ParametersData", "]"}], "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", "\"\< and CIs = \>\"", 
      ",", 
      RowBox[{
       RowBox[{"Sort", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", "ParametersData", "]"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"Max", "[", 
         RowBox[{"1", ",", 
          RowBox[{"Round", "[", 
           RowBox[{"0.5", "*", 
            RowBox[{"(", 
             RowBox[{"1", "-", "CI"}], ")"}], "*", "mCI"}], "]"}]}], "]"}], 
        "]"}], "]"}], ",", "\"\< --- \>\"", ",", 
      RowBox[{
       RowBox[{"Sort", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", "ParametersData", "]"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"Round", "[", 
         RowBox[{"0.5", "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", "CI"}], ")"}], "*", "mCI"}], "]"}], "]"}], 
       "]"}]}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.6745599614534073`*^9, 3.674559966107534*^9}, {
   3.6745784597329187`*^9, 3.674578459804841*^9}, {3.67457889587926*^9, 
   3.67457889982087*^9}, 3.674579346746333*^9, {3.715637417931089*^9, 
   3.715637424775936*^9}, {3.715696932669087*^9, 3.71569693415392*^9}, {
   3.719965050546959*^9, 3.7199650509784946`*^9}}],

Cell[BoxData["1000"], "Output",
 CellChangeTimes->{3.674593732351849*^9, 3.674593948644376*^9, 
  3.715621860420854*^9, 3.715637470501689*^9, 3.71996509307716*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Mean and Bootstrap \"\>", "\[InvisibleSpace]", "95", 
   "\[InvisibleSpace]", "\<\"% confindence intervals (based on \"\>", 
   "\[InvisibleSpace]", "1000", "\[InvisibleSpace]", "\<\" resamplings)\"\>"}],
  SequenceForm[
  "Mean and Bootstrap ", 95, "% confindence intervals (based on ", 1000, 
   " resamplings)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.67459373235913*^9, 3.674593948654435*^9, 
  3.715621860429638*^9, 3.715637470511166*^9, 3.719965093086525*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"F0 = \"\>", "\[InvisibleSpace]", "1.435397947235927`*^-10", 
   "\[InvisibleSpace]", "\<\" mean bootstrap = \"\>", "\[InvisibleSpace]", 
   "0.014176467918081706`", "\[InvisibleSpace]", "\<\" and CIs = \"\>", 
   "\[InvisibleSpace]", "0.0009624609833895386`", 
   "\[InvisibleSpace]", "\<\" --- \"\>", "\[InvisibleSpace]", 
   "0.04851094421547186`"}],
  SequenceForm[
  "F0 = ", 1.435397947235927*^-10, " mean bootstrap = ", 
   0.014176467918081706`, " and CIs = ", 0.0009624609833895386, " --- ", 
   0.04851094421547186],
  Editable->False]], "Print",
 CellChangeTimes->{3.67459373235913*^9, 3.674593948654435*^9, 
  3.715621860429638*^9, 3.715637470511166*^9, 3.7199650930916147`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"e = \"\>", "\[InvisibleSpace]", "0.11516017274748384`", 
   "\[InvisibleSpace]", "\<\" mean bootstrap = \"\>", "\[InvisibleSpace]", 
   "0.0190679044830364`", "\[InvisibleSpace]", "\<\" and CIs = \"\>", 
   "\[InvisibleSpace]", "0.012167365166866864`", 
   "\[InvisibleSpace]", "\<\" --- \"\>", "\[InvisibleSpace]", 
   "0.028969284445324248`"}],
  SequenceForm[
  "e = ", 0.11516017274748384`, " mean bootstrap = ", 0.0190679044830364, 
   " and CIs = ", 0.012167365166866864`, " --- ", 0.028969284445324248`],
  Editable->False]], "Print",
 CellChangeTimes->{3.67459373235913*^9, 3.674593948654435*^9, 
  3.715621860429638*^9, 3.715637470511166*^9, 3.719965093096562*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"    1 - F0\\nLog[------]\\n      F0\\n-----------\\n     e = \
\"\>", "\[InvisibleSpace]", "196.80770064126432`", 
   "\[InvisibleSpace]", "\<\" mean bootstrap = \"\>", "\[InvisibleSpace]", 
   "246.24315376865863`", "\[InvisibleSpace]", "\<\" and CIs = \"\>", 
   "\[InvisibleSpace]", "194.8698945345784`", 
   "\[InvisibleSpace]", "\<\" --- \"\>", "\[InvisibleSpace]", 
   "307.3235379997024`"}],
  SequenceForm[
  "    1 - F0\nLog[------]\n      F0\n-----------\n     e = ", 
   196.80770064126432`, " mean bootstrap = ", 246.24315376865863`, 
   " and CIs = ", 194.8698945345784, " --- ", 307.3235379997024],
  Editable->False]], "Print",
 CellChangeTimes->{3.67459373235913*^9, 3.674593948654435*^9, 
  3.715621860429638*^9, 3.715637470511166*^9, 3.719965093101548*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", 
  RowBox[{
   RowBox[{"ParametersData", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"All", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Frame", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<escape rate\>\"", ",", "\"\<runs\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.674560041452886*^9, 3.674560043167383*^9}, {
  3.674560255139575*^9, 3.674560267266696*^9}, {3.674560817387679*^9, 
  3.674560827090962*^9}, {3.674560890463786*^9, 3.674560895686297*^9}, {
  3.674568965981241*^9, 3.674568970205052*^9}, {3.674569080047258*^9, 
  3.6745691055569572`*^9}, {3.67456963701151*^9, 3.674569637737956*^9}, {
  3.674569938422112*^9, 3.674569938574121*^9}, {3.6745785168872423`*^9, 
  3.674578532374761*^9}, {3.715637452670817*^9, 3.7156374534938393`*^9}, {
  3.719965080897352*^9, 3.719965083082144*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.588], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.588], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.008, 0}, {0.01, 2}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{46.25, 69.25}, {93.76430934741155, 
          96.3813728906053}}],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.01, 0}, {0.012, 21}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{68.75, 91.74999999999999}, {73.65220568707093, 
          96.3813728906053}}],
        StatusArea[#, 21]& ,
        TagBoxNote->"21"],
       StyleBox["21", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[21, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.012, 0}, {0.014, 74}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{91.24999999999999, 114.24999999999999`}, {
          17.55002179243654, 96.3813728906053}}],
        StatusArea[#, 74]& ,
        TagBoxNote->"74"],
       StyleBox["74", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[74, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.014, 0}, {0.016, 147}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{113.74999999999999`, 136.75}, {-59.72279753413535, 
          96.3813728906053}}],
        StatusArea[#, 147]& ,
        TagBoxNote->"147"],
       StyleBox["147", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[147, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.016, 0}, {0.018, 208}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{136.25, 
          159.24999999999994`}, {-124.29323560154474`, 96.3813728906053}}],
        StatusArea[#, 208]& ,
        TagBoxNote->"208"],
       StyleBox["208", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[208, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.018, 0}, {0.02, 179}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{158.74999999999994`, 181.75}, {-93.59581422523534, 
          96.3813728906053}}],
        StatusArea[#, 179]& ,
        TagBoxNote->"179"],
       StyleBox["179", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[179, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.02, 0}, {0.022, 145}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{181.25, 204.24999999999994`}, {-57.6057339909416, 
          96.3813728906053}}],
        StatusArea[#, 145]& ,
        TagBoxNote->"145"],
       StyleBox["145", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[145, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.022, 0}, {0.024, 97}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{203.74999999999994`, 
          226.74999999999994`}, {-6.796208954291586, 96.3813728906053}}],
        StatusArea[#, 97]& ,
        TagBoxNote->"97"],
       StyleBox["97", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[97, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.024, 0}, {0.026, 55}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{226.24999999999994`, 249.24999999999994`}, {
          37.66212545277717, 96.3813728906053}}],
        StatusArea[#, 55]& ,
        TagBoxNote->"55"],
       StyleBox["55", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[55, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.026, 0}, {0.028, 36}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{248.74999999999994`, 271.74999999999994`}, {
          57.7742291131178, 96.3813728906053}}],
        StatusArea[#, 36]& ,
        TagBoxNote->"36"],
       StyleBox["36", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[36, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.028, 0}, {0.03, 21}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{271.24999999999994`, 294.24999999999994`}, {
          73.65220568707093, 96.3813728906053}}],
        StatusArea[#, 21]& ,
        TagBoxNote->"21"],
       StyleBox["21", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[21, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.03, 0}, {0.032, 5}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{293.74999999999994`, 316.74999999999994`}, {
          90.58871403262093, 96.3813728906053}}],
        StatusArea[#, 5]& ,
        TagBoxNote->"5"],
       StyleBox["5", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[5, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.032, 0}, {0.034, 4}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{316.24999999999994`, 339.24999999999994`}, {
          91.6472458042178, 96.3813728906053}}],
        StatusArea[#, 4]& ,
        TagBoxNote->"4"],
       StyleBox["4", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[4, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.034, 0}, {0.036, 4}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{338.74999999999994`, 361.7499999999999}, {
          91.6472458042178, 96.3813728906053}}],
        StatusArea[#, 4]& ,
        TagBoxNote->"4"],
       StyleBox["4", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[4, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.038, 0}, {0.04, 2}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{383.74999999999994`, 406.74999999999994`}, {
          93.76430934741155, 96.3813728906053}}],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], 
       "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.00736, 0},
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"runs\"", TraditionalForm], None}, {
     FormBox["\"escape rate\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{420, 280},
  PlotRange->{{0.008, 0.04}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {None, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.674593732465391*^9, 3.6745939650506487`*^9, 
  3.715621860600314*^9, 3.7156374707163773`*^9, 3.7199651055061407`*^9}]
}, Open  ]],

Cell["\<\
Here we look at the ii\[CloseCurlyQuote]s bootstrap, compare how it was \
different from the original data and plot the best fit line. Original data \
are given by bullets, and resampled bootstraps are given by red triangles.\
\>", "Text",
 CellChangeTimes->{{3.715636769887259*^9, 3.715636833997158*^9}, {
  3.715637381483746*^9, 3.715637407191716*^9}, {3.715637516739068*^9, 
  3.715637586564413*^9}, {3.715637705422276*^9, 3.715637721588801*^9}},
 FontSize->18,
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ii", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ParF", "/.", 
  RowBox[{"solData0", "[", 
   RowBox[{"[", 
    RowBox[{"ii", ",", "2"}], "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BootstrapData", "[", 
   RowBox[{"[", "ii", "]"}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"All", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"BootstrapData", "[", 
        RowBox[{"[", "ii", "]"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotMarkers", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[FilledUpTriangle]\>\"", ",", "18"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "20"}], ",", "450"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.05"}], ",", "1.05"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<days since symptoms\>\"", ",", "\"\<escape frequency\>\""}], 
       "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
        RowBox[{"FontFamily", "\[Rule]", "Times"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"datasetT", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotMarkers", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\[FilledCircle]\>\"", ",", "16"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "\[IndentingNewLine]", 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", 
          RowBox[{"f", "[", 
           RowBox[{"t", ",", 
            RowBox[{"ParF", "/.", 
             RowBox[{"solData0", "[", 
              RowBox[{"[", 
               RowBox[{"ii", ",", "2"}], "]"}], "]"}]}]}], "]"}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.04"}], ",", "1.01"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotMarkers", "\[Rule]", "None"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "\[IndentingNewLine]", "]"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", 
          RowBox[{"f", "[", 
           RowBox[{"t", ",", 
            RowBox[{"ParF", "/.", 
             RowBox[{"sol", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "tmax"}], "}"}]}], "]"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotMarkers", "\[Rule]", "None"}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]}], "Input",
 CellChangeTimes->{{3.674561172875615*^9, 3.674561360317642*^9}, {
   3.6745685623575573`*^9, 3.6745685833102627`*^9}, 3.674568622832662*^9, {
   3.674568655461133*^9, 3.674568666714931*^9}, {3.6745687124771433`*^9, 
   3.6745687325806503`*^9}, {3.674568872411231*^9, 3.674568881516609*^9}, {
   3.6745690154280977`*^9, 3.6745690534573717`*^9}, {3.674569406497064*^9, 
   3.6745694070635*^9}, {3.6745694869173193`*^9, 3.674569524487809*^9}, {
   3.674569582792829*^9, 3.6745696274158993`*^9}, {3.6745699193697987`*^9, 
   3.674569931999879*^9}, {3.6745785043707333`*^9, 3.674578506864748*^9}, {
   3.674578556976149*^9, 3.6745785914972353`*^9}, {3.674578676520245*^9, 
   3.674578712795561*^9}, {3.674578782203588*^9, 3.6745787829645433`*^9}, {
   3.674578959110203*^9, 3.674578959269423*^9}, {3.674579425019168*^9, 
   3.674579494470353*^9}, {3.674579576693409*^9, 3.67457957682673*^9}, {
   3.67457992744178*^9, 3.674580041663108*^9}, {3.6745802723046722`*^9, 
   3.674580281520226*^9}, {3.674580574037867*^9, 3.674580574140236*^9}, {
   3.674593280809628*^9, 3.674593280993766*^9}, {3.715621846501795*^9, 
   3.715621857428853*^9}, {3.7156219101259537`*^9, 3.7156220265156717`*^9}, {
   3.715637597691732*^9, 3.715637673271461*^9}, {3.715637724415753*^9, 
   3.715637724622579*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.026594036464602788`", ",", "0.010962155368166929`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.674561181316551*^9, 3.6745612399663963`*^9}, {
   3.674561298258463*^9, 3.674561360746014*^9}, 3.674568522754859*^9, 
   3.674568564458493*^9, 3.674568623577517*^9, {3.674568656261703*^9, 
   3.674568667120895*^9}, {3.6745687132590437`*^9, 3.674568733243108*^9}, 
   3.67456893756752*^9, {3.674569032882303*^9, 3.67456905388776*^9}, 
   3.6745694074564877`*^9, 3.674569489280919*^9, {3.674569585141079*^9, 
   3.674569627881279*^9}, {3.674569909754559*^9, 3.6745699324012003`*^9}, {
   3.6745784922615967`*^9, 3.6745785096052227`*^9}, {3.674578557891097*^9, 
   3.674578592051236*^9}, {3.674578679845294*^9, 3.6745787134821253`*^9}, 
   3.674578783800108*^9, 3.674578904866837*^9, 3.67457895968178*^9, 
   3.67457913120223*^9, {3.674579450642164*^9, 3.674579496096065*^9}, 
   3.674579577218713*^9, 3.6745796670999107`*^9, 3.6745797913158197`*^9, 
   3.6745799221292877`*^9, {3.67457995315775*^9, 3.67457997830982*^9}, {
   3.67458001085832*^9, 3.6745800424440393`*^9}, 3.674580219685066*^9, {
   3.674580273212488*^9, 3.674580281968342*^9}, {3.6745804371163683`*^9, 
   3.674580450333788*^9}, {3.674580547524562*^9, 3.674580574693027*^9}, 
   3.6745926785275517`*^9, 3.674592949256802*^9, {3.6745932706281652`*^9, 
   3.6745932814789257`*^9}, 3.674593542801601*^9, 3.674593760149517*^9, 
   3.674593975426662*^9, 3.715621863958009*^9, 3.7156219241988697`*^9, {
   3.7156219858218927`*^9, 3.7156220270575733`*^9}, {3.715637588145746*^9, 
   3.7156376742824287`*^9}, 3.7156377253622017`*^9, 3.719965110680266*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0.0029276257888750253`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"16", ",", "0.056031058967147614`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"45", ",", "0.06713215329662585`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"111", ",", "0.09493441908983893`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"181", ",", "0.1858176305891066`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"412", ",", "0.7032197167445184`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.674561181316551*^9, 3.6745612399663963`*^9}, {
   3.674561298258463*^9, 3.674561360746014*^9}, 3.674568522754859*^9, 
   3.674568564458493*^9, 3.674568623577517*^9, {3.674568656261703*^9, 
   3.674568667120895*^9}, {3.6745687132590437`*^9, 3.674568733243108*^9}, 
   3.67456893756752*^9, {3.674569032882303*^9, 3.67456905388776*^9}, 
   3.6745694074564877`*^9, 3.674569489280919*^9, {3.674569585141079*^9, 
   3.674569627881279*^9}, {3.674569909754559*^9, 3.6745699324012003`*^9}, {
   3.6745784922615967`*^9, 3.6745785096052227`*^9}, {3.674578557891097*^9, 
   3.674578592051236*^9}, {3.674578679845294*^9, 3.6745787134821253`*^9}, 
   3.674578783800108*^9, 3.674578904866837*^9, 3.67457895968178*^9, 
   3.67457913120223*^9, {3.674579450642164*^9, 3.674579496096065*^9}, 
   3.674579577218713*^9, 3.6745796670999107`*^9, 3.6745797913158197`*^9, 
   3.6745799221292877`*^9, {3.67457995315775*^9, 3.67457997830982*^9}, {
   3.67458001085832*^9, 3.6745800424440393`*^9}, 3.674580219685066*^9, {
   3.674580273212488*^9, 3.674580281968342*^9}, {3.6745804371163683`*^9, 
   3.674580450333788*^9}, {3.674580547524562*^9, 3.674580574693027*^9}, 
   3.6745926785275517`*^9, 3.674592949256802*^9, {3.6745932706281652`*^9, 
   3.6745932814789257`*^9}, 3.674593542801601*^9, 3.674593760149517*^9, 
   3.674593975426662*^9, 3.715621863958009*^9, 3.7156219241988697`*^9, {
   3.7156219858218927`*^9, 3.7156220270575733`*^9}, {3.715637588145746*^9, 
   3.7156376742824287`*^9}, 3.7156377253622017`*^9, 3.7199651106908827`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[1, 0, 0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      StyleBox[GeometricTransformationBox[InsetBox[
         StyleBox["\<\"\[FilledUpTriangle]\"\>",
          StripOnInput->False,
          FontSize->18], {0., 0.}], {{{0., 0.0029276257888750253`}}, {{16., 
        0.056031058967147614`}}, {{45., 0.06713215329662585}}, {{111., 
        0.09493441908983893}}, {{181., 0.1858176305891066}}, {{412., 
        0.7032197167445184}}}],
       FontFamily->Times,
       FontSize->16]}, {}}, {}, {}, {{}, {}}}, {{}, {
     {GrayLevel[0], AbsolutePointSize[6], AbsoluteThickness[1.6], 
      GeometricTransformationBox[InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->16], {0., 0.}], {{{0., 0.}}, {{16., 0.}}, {{45., 0.}}, {{
       111., 0.}}, {{181., 0.14}}, {{412., 
       1.}}}]}, {}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[1, 0, 0], PointSize[0.007333333333333334], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw11nlczIn/B/CPI2eRr7t2a3QrmyJXLb2UQqI7Ssd03zXTTDOF9IkIuyhn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       "]]}}, {}, {}, {{}, {}}}, {{}, {{}, {}, 
     {GrayLevel[0], PointSize[0.007333333333333334], AbsoluteThickness[1.6], 
      LineBox[CompressedData["
1:eJxd1Xk4lfn/x/GDTCUTzVSTZJJSGKFUKhkvQtpljahjy87Zz0mbom1kUtM6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       "]]}}, {}, {}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontSize -> 16, FontFamily -> Times},
  DisplayFunction->Identity,
  Frame->{{True, False}, {True, False}},
  FrameLabel->{{
     FormBox["\"escape frequency\"", TraditionalForm], None}, {
     FormBox["\"days since symptoms\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-20, 450}, {-0.05, 1.05}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.674561181316551*^9, 3.6745612399663963`*^9}, {
   3.674561298258463*^9, 3.674561360746014*^9}, 3.674568522754859*^9, 
   3.674568564458493*^9, 3.674568623577517*^9, {3.674568656261703*^9, 
   3.674568667120895*^9}, {3.6745687132590437`*^9, 3.674568733243108*^9}, 
   3.67456893756752*^9, {3.674569032882303*^9, 3.67456905388776*^9}, 
   3.6745694074564877`*^9, 3.674569489280919*^9, {3.674569585141079*^9, 
   3.674569627881279*^9}, {3.674569909754559*^9, 3.6745699324012003`*^9}, {
   3.6745784922615967`*^9, 3.6745785096052227`*^9}, {3.674578557891097*^9, 
   3.674578592051236*^9}, {3.674578679845294*^9, 3.6745787134821253`*^9}, 
   3.674578783800108*^9, 3.674578904866837*^9, 3.67457895968178*^9, 
   3.67457913120223*^9, {3.674579450642164*^9, 3.674579496096065*^9}, 
   3.674579577218713*^9, 3.6745796670999107`*^9, 3.6745797913158197`*^9, 
   3.6745799221292877`*^9, {3.67457995315775*^9, 3.67457997830982*^9}, {
   3.67458001085832*^9, 3.6745800424440393`*^9}, 3.674580219685066*^9, {
   3.674580273212488*^9, 3.674580281968342*^9}, {3.6745804371163683`*^9, 
   3.674580450333788*^9}, {3.674580547524562*^9, 3.674580574693027*^9}, 
   3.6745926785275517`*^9, 3.674592949256802*^9, {3.6745932706281652`*^9, 
   3.6745932814789257`*^9}, 3.674593542801601*^9, 3.674593760149517*^9, 
   3.674593975426662*^9, 3.715621863958009*^9, 3.7156219241988697`*^9, {
   3.7156219858218927`*^9, 3.7156220270575733`*^9}, {3.715637588145746*^9, 
   3.7156376742824287`*^9}, 3.7156377253622017`*^9, 3.7199651107915916`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Re", "-", 
    RowBox[{"fit", " ", "the", " ", "data"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"minimum2r", "[", 
   RowBox[{
    RowBox[{"BootstrapData", "[", 
     RowBox[{"[", "ii", "]"}], "]"}], ",", "ssq", ",", "ParF", ",", "Par00", 
    ",", "ConPars"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.67457876855217*^9, 3.674578774108384*^9}, {
  3.674578805428084*^9, 3.6745788184814367`*^9}, {3.674578918096006*^9, 
  3.674578921823419*^9}, {3.674579157477426*^9, 3.674579163171986*^9}, {
  3.6745795620001307`*^9, 3.674579568089644*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"20.09986764735018`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"F0", "\[Rule]", "0.026594036464602788`"}], ",", 
     RowBox[{"e", "\[Rule]", "0.010962155368166929`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.6745787745871067`*^9, 3.674578819190518*^9}, {
   3.674578908938758*^9, 3.674578922141056*^9}, {3.674579140903201*^9, 
   3.674579163594686*^9}, {3.67457955579249*^9, 3.674579569398546*^9}, 
   3.674580592793841*^9, 3.715622036240282*^9, 3.715637688652302*^9, 
   3.719965119535733*^9}]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1392, 855},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792},
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "fly10", 
   "vitaly"}, "picture-1.ps", CharacterEncoding -> "iso8859-1"]},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 548, 19, 232, "Title"],
Cell[CellGroupData[{
Cell[1131, 43, 401, 7, 44, "Subsection"],
Cell[1535, 52, 163, 3, 35, "Text"],
Cell[1701, 57, 8160, 215, 327, "Input"],
Cell[9864, 274, 416, 10, 59, "Text"],
Cell[10283, 286, 2708, 60, 159, "Input"],
Cell[12994, 348, 1186, 25, 107, "Text"],
Cell[CellGroupData[{
Cell[14205, 377, 7119, 206, 621, "Input"],
Cell[21327, 585, 1592, 25, 24, "Print"],
Cell[22922, 612, 1640, 27, 24, "Print"],
Cell[24565, 641, 1347, 18, 32, "Output"]
}, Open  ]],
Cell[25927, 662, 382, 8, 59, "Text"],
Cell[CellGroupData[{
Cell[26334, 674, 2844, 66, 369, "Input"],
Cell[29181, 742, 7644, 135, 253, "Output"]
}, Open  ]],
Cell[36840, 880, 382, 8, 59, "Text"],
Cell[CellGroupData[{
Cell[37247, 892, 1115, 30, 117, "Input"],
Cell[38365, 924, 438, 9, 24, "Message"],
Cell[38806, 935, 457, 11, 35, "Output"],
Cell[39266, 948, 326, 7, 35, "Output"]
}, Open  ]],
Cell[39607, 958, 221, 4, 35, "Text"],
Cell[CellGroupData[{
Cell[39853, 966, 2843, 66, 369, "Input"],
Cell[42699, 1034, 7093, 129, 253, "Output"]
}, Open  ]],
Cell[49807, 1166, 284, 5, 35, "Text"],
Cell[50094, 1173, 2105, 59, 159, "Input"],
Cell[52202, 1234, 281, 5, 35, "Text"],
Cell[52486, 1241, 669, 16, 54, "Input"],
Cell[53158, 1259, 430, 9, 35, "Text"],
Cell[CellGroupData[{
Cell[53613, 1272, 3711, 106, 285, "Input"],
Cell[57327, 1380, 163, 2, 32, "Output"],
Cell[57493, 1384, 526, 10, 24, "Print"],
Cell[58022, 1396, 738, 14, 25, "Print"],
Cell[58763, 1412, 722, 13, 24, "Print"],
Cell[59488, 1427, 823, 15, 101, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60348, 1447, 1182, 24, 117, "Input"],
Cell[61533, 1473, 10349, 298, 295, "Output"]
}, Open  ]],
Cell[71897, 1774, 505, 9, 59, "Text"],
Cell[CellGroupData[{
Cell[72427, 1787, 5591, 134, 642, "Input"],
Cell[78021, 1923, 1651, 24, 32, "Output"],
Cell[79675, 1949, 2067, 35, 32, "Output"],
Cell[81745, 1986, 14569, 247, 251, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96351, 2238, 613, 14, 54, "Input"],
Cell[96967, 2254, 556, 12, 32, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

